Instructions on how to report a bug to the Bibulous development team — Bibulous 1.2 documentation

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- home|
- search|

# Instructions on how to report a bug to the Bibulous development team

## Where to report a bug

Send an email to the `users_mailing_list`. Once it’s confirmed as a bug, someone, possibly you, can enter it into the issue tracker. (Or if you’re pretty sure about the bug, go ahead and post directly to the developers mailing list, `developers_mailing_list`. But if you’re not sure, it’s better to post to [`users mailing list`] first; someone there can tell you whether the behavior you encountered is expected or not.)

## How to report a bug

First, make sure it’s a bug. If Bibulous does not behave the way you expect, look in the documentation and mailing list archives for evidence that it should behave the way you expect. If the documentation and archives do not contain enough information to tell you whether the behavior is a bug or is expected behavior, go ahead and ask on the users mailing list first `users_mailing_list`. Also check that you are running the most recent version of Bibulous. It may be that the bug has already been fixed.

Once you’ve established that it’s a bug, the most important thing you can do is come up with a simple description and reproduction recipe. For example, if the bug, as you initially found it, involves five files over ten commits, try to make it happen with just one file and one commit. The simpler the reproduction recipe, the more likely a developer is to successfully reproduce the bug and fix it.

When you write up the reproduction recipe, don’t just write a prose description of what you did to make the bug happen. Instead, give a copy of the exact series of commands you ran, and their output. Use cut-and-paste to do this. If there are files involved, be sure to include the names of the files, and even their content if you think it might be relevant. The very best thing is to package your reproduction recipe as a script, that helps a lot.

In addition to the reproduction recipe, we’ll also need a complete description of the environment in which you reproduced the bug. That means:

- Your operating system
- The Python version you are running under.
- The release and/or revision of Bibulous.
- Anything else that could possibly be relevant. Err on the side of too much information, rather than too little.

Once you have all this, you’re ready to write the report. Start out with a clear description of what the bug is. That is, say how you expected Bibulous to behave, and contrast that with how it actually behaved. While the bug may seem obvious to you, it may not be so obvious to someone else, so it’s best to avoid a guessing game. Follow that with the environment description, and the reproduction recipe. If you also want to include speculation as to the cause, and even suggest how the code may be modified to fix the bug, that’s great.

Post all of this information to the developers mailing list, `developers_mailing_list`, or if you have already been there and been asked to file an issue, then go to the Issue Tracker and follow the instructions there.

Thanks! It’s a lot of work to file an effective bug report, but a good report can save hours of a developer’s time, and make the bug much more likely to get fixed.

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- home|
- search|